@@ -47,14 +47,16 @@ class Serialization(WikiSerialization):
         if download:
             external = False
 
+        wiki = None
         if alpha or beta or external:
             config_var = build_config_var(alpha, beta, external)
             logging.debug('looking for %s', config_var)
             file = self.environ.get('tiddlyweb.config', {}).get(config_var, '')
             if file:
                 logging.debug('using %s as base_tiddlywiki', file)
-                return read_utf8_file(file)
-        wiki = WikiSerialization._get_wiki(self)
+                wiki = read_utf8_file(file)
+        if not wiki:
+            wiki = WikiSerialization._get_wiki(self)
         tag = "<!--POST-SCRIPT-END-->"
         wiki = wiki.replace(tag, '''
           <script type="text/javascript" src="/bags/common/tiddlers/backstage.js"></script>
