@@ -25,10 +25,10 @@ config = {
     'atom.default_filter': 'select=tag:!excludeLists;sort=-modified;limit=20',
     'atom.author_uri_map': '/profiles/%s',
     'atom.hub': 'http://pubsubhubbub.appspot.com/',
+    'auth_systems': ['tiddlywebplugins.tiddlyspace.cookie_form',
+        'tiddlywebplugins.tiddlyspace.openid'],
     'beanstalk.listeners': ['tiddlywebplugins.dispatcher.listener',
         'tiddlywebplugins.tiddlyspace.profiles'],
-    'auth_systems': ['cookie_form',
-        'tiddlywebplugins.tiddlyspace.openid'],
     'bag_create_policy': 'ANY',
     'recipe_create_policy': 'ANY',
     'css_uri': '/bags/common/tiddlers/tiddlyweb.css',
