@@ -2,7 +2,7 @@
 https://raw.github.com/TiddlySpace/ts.js/master/src/ts.js
 ***/
 //{{{
-// version 0.5.3
+// version 0.5.5
 (function() {
 var getCSRFToken = function(window) {
 	// XXX: should not use RegEx - cf.
@@ -527,10 +527,30 @@ var ts = {
 					val(window.location.pathname + querystring + "#auth:OpenID=" + identity).appendTo(form);
 			});
 		},
-		logout: function(container) {
-			var form = $('<form method="POST" />').attr("action", "/logout").appendTo(container)[0];
+		logout: function(form_or_container) {
+			if(!form_or_container) {
+				return;
+			}
+			var tag = form_or_container.nodeName;
+			var form;
+			var isContainer = tag !== "FORM";
+			if(isContainer) {
+				var uri = ts.getHost(ts.user.name);
+				var link = $("<a />").attr({"href": uri,
+					"target": "_parent"}).text(ts.user.name)[0];
+				var msg = $("<span class='message' />").text("Welcome back ").prependTo(form_or_container)[0];
+				$(msg).append(link);
+				$("<span />").text("!").appendTo(msg);
+				form = $("form", form_or_container)[0];
+				if(!form) {
+					form = $('<form />').appendTo(form_or_container)[0];
+					$('<input type="submit" class="button" value="Log out">').appendTo(form);
+				}
+			}  else {
+				form = form_or_container;
+			}
+			$(form).attr("action", "/logout").attr("method", "post");
 			ts.forms._csrf(form);
-			$('<input type="submit" class="button" value="Log out">').appendTo(form);
 		},
 		login: function(form) {
 			// do login
@@ -570,18 +590,9 @@ var ts = {
 		if(!user.anon) {
 			$(document.body).addClass("ts-loggedin");
 			$([register, login]).remove();
-			if(!logout) {
-				return;
-			}
-			$(logout).empty();
-			var container = logout;
-			var uri = ts.getHost(user.name);
-			var link = $("<a />").attr({"href": uri,
-				"target": "_parent"}).text(user.name)[0];
-			$("<span />").text("Welcome back ").appendTo(container);
-			$(container).append(link);
-			$("<span />").text("!").appendTo(container);
-			ts.forms.logout(container);
+			$(".ts-logout").each(function(i, el) {
+				ts.forms.logout(el);
+			});
 		} else {
 			if(register) {
 				ts.forms.register(register);
@@ -589,8 +600,7 @@ var ts = {
 			if(login) {
 				ts.forms.login(login);
 			}
-
-			$(logout).remove();
+			$(".ts-logout").remove();
 		}
 	}
 };
